---
title: App Router
description: The App Router is a file-system based router that uses React's latest features such as Server Components, Suspense, Server Functions, and more.
related:
  title: Next Steps
  description: Learn the fundamentals of building an App Router project, from installation to layouts, navigation, server and client components.
  links:
    - app/getting-started/installation
    - app/getting-started/project-structure
    - app/getting-started/layouts-and-pages
    - app/getting-started/linking-and-navigating
    - app/getting-started/server-and-client-components
---

The **App Router** is a file-system based router that uses React's latest features such as [Server Components](https://react.dev/reference/rsc/server-components), [Suspense](https://react.dev/reference/react/Suspense), and [Server Functions](https://react.dev/reference/rsc/server-functions).
